"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def meter_usage(ProductCode=None, Timestamp=None, UsageDimension=None, UsageQuantity=None, DryRun=None):
    """
    :param ProductCode: [REQUIRED]
            Product code is used to uniquely identify a product in AWS Marketplace. The product code should be the same as the one used during the publishing of a new product.
            
    :type ProductCode: string
    :param Timestamp: [REQUIRED]
            Timestamp of the hour, recorded in UTC. The seconds and milliseconds portions of the timestamp will be ignored.
            
    :type Timestamp: datetime
    :param UsageDimension: [REQUIRED]
            It will be one of the 'fcp dimension name' provided during the publishing of the product.
            
    :type UsageDimension: string
    :param UsageQuantity: [REQUIRED]
            Consumption value for the hour.
            
    :type UsageQuantity: integer
    :param DryRun: [REQUIRED]
            Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns DryRunOperation; otherwise, it returns UnauthorizedException.
            
    :type DryRun: boolean
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def batch_check_layer_availability(registryId=None, repositoryName=None, layerDigests=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the image layers to check. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository that is associated with the image layers to check.
            
    :type repositoryName: string
    :param layerDigests: [REQUIRED]
            The digests of the image layers to check.
            (string) --
            
    :type layerDigests: list
    """
    pass

def batch_delete_image(registryId=None, repositoryName=None, imageIds=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the image to delete. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The repository that contains the image to delete.
            
    :type repositoryName: string
    :param imageIds: [REQUIRED]
            A list of image ID references that correspond to images to delete. The format of the imageIds reference is imageTag=tag or imageDigest=digest .
            (dict) --An object with identifying information for an Amazon ECR image.
            imageDigest (string) --The sha256 digest of the image manifest.
            imageTag (string) --The tag used for the image.
            
            
    :type imageIds: list
    """
    pass

def batch_get_image(registryId=None, repositoryName=None, imageIds=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the images to describe. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The repository that contains the images to describe.
            
    :type repositoryName: string
    :param imageIds: [REQUIRED]
            A list of image ID references that correspond to images to describe. The format of the imageIds reference is imageTag=tag or imageDigest=digest .
            (dict) --An object with identifying information for an Amazon ECR image.
            imageDigest (string) --The sha256 digest of the image manifest.
            imageTag (string) --The tag used for the image.
            
            
    :type imageIds: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def complete_layer_upload(registryId=None, repositoryName=None, uploadId=None, layerDigests=None):
    """
    :param registryId: The AWS account ID associated with the registry to which to upload layers. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository to associate with the image layer.
            
    :type repositoryName: string
    :param uploadId: [REQUIRED]
            The upload ID from a previous InitiateLayerUpload operation to associate with the image layer.
            
    :type uploadId: string
    :param layerDigests: [REQUIRED]
            The sha256 digest of the image layer.
            (string) --
            
    :type layerDigests: list
    """
    pass

def create_repository(repositoryName=None):
    """
    :param repositoryName: [REQUIRED]
            The name to use for the repository. The repository name may be specified on its own (such as nginx-web-app ) or it can be prepended with a namespace to group the repository into a category (such as project-a/nginx-web-app ).
            Return typedict
            ReturnsResponse Syntax{
              'repository': {
                'repositoryArn': 'string',
                'registryId': 'string',
                'repositoryName': 'string',
                'repositoryUri': 'string',
                'createdAt': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --
            repository (dict) --The repository that was created.
            repositoryArn (string) --The Amazon Resource Name (ARN) that identifies the repository. The ARN contains the arn:aws:ecr namespace, followed by the region of the repository, the AWS account ID of the repository owner, the repository namespace, and then the repository name. For example, arn:aws:ecr:region:012345678910:repository/test .
            registryId (string) --The AWS account ID associated with the registry that contains the repository.
            repositoryName (string) --The name of the repository.
            repositoryUri (string) --The URI for the repository. You can use this URI for Docker push and pull operations.
            createdAt (datetime) --The date and time, in JavaScript date/time format, when the repository was created.
            
            
            
    :type repositoryName: string
    """
    pass

def delete_repository(registryId=None, repositoryName=None, force=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository to delete. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository to delete.
            
    :type repositoryName: string
    :param force: Force the deletion of the repository if it contains images.
    :type force: boolean
    """
    pass

def delete_repository_policy(registryId=None, repositoryName=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository policy to delete. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository that is associated with the repository policy to delete.
            
    :type repositoryName: string
    """
    pass

def describe_images(registryId=None, repositoryName=None, imageIds=None, nextToken=None, maxResults=None, filter=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository in which to list images. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            A list of repositories to describe. If this parameter is omitted, then all repositories in a registry are described.
            
    :type repositoryName: string
    :param imageIds: The list of image IDs for the requested repository.
            (dict) --An object with identifying information for an Amazon ECR image.
            imageDigest (string) --The sha256 digest of the image manifest.
            imageTag (string) --The tag used for the image.
            
            
    :type imageIds: list
    :param nextToken: The nextToken value returned from a previous paginated DescribeImages request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
    :type nextToken: string
    :param maxResults: The maximum number of repository results returned by DescribeImages in paginated output. When this parameter is used, DescribeImages only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeImages request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then DescribeImages returns up to 100 results and a nextToken value, if applicable.
    :type maxResults: integer
    :param filter: The filter key and value with which to filter your DescribeImages results.
            tagStatus (string) --The tag status with which to filter your DescribeImages results. You can filter results based on whether they are TAGGED or UNTAGGED .
            
    :type filter: dict
    """
    pass

def describe_repositories(registryId=None, repositoryNames=None, nextToken=None, maxResults=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repositories to be described. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryNames: A list of repositories to describe. If this parameter is omitted, then all repositories in a registry are described.
            (string) --
            
    :type repositoryNames: list
    :param nextToken: The nextToken value returned from a previous paginated DescribeRepositories request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
            Note
            This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
            
    :type nextToken: string
    :param maxResults: The maximum number of repository results returned by DescribeRepositories in paginated output. When this parameter is used, DescribeRepositories only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeRepositories request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then DescribeRepositories returns up to 100 results and a nextToken value, if applicable.
    :type maxResults: integer
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_authorization_token(registryIds=None):
    """
    :param registryIds: A list of AWS account IDs that are associated with the registries for which to get authorization tokens. If you do not specify a registry, the default registry is assumed.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'authorizationData': [
                {
                  'authorizationToken': 'string',
                  'expiresAt': datetime(2015, 1, 1),
                  'proxyEndpoint': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            authorizationData (list) --A list of authorization token data objects that correspond to the registryIds values in the request.
            (dict) --An object representing authorization data for an Amazon ECR registry.
            authorizationToken (string) --A base64-encoded string that contains authorization data for the specified Amazon ECR registry. When the string is decoded, it is presented in the format user:password for private registry authentication using docker login .
            expiresAt (datetime) --The Unix time in seconds and milliseconds when the authorization token expires. Authorization tokens are valid for 12 hours.
            proxyEndpoint (string) --The registry URL to use for this authorization token in a docker login command. The Amazon ECR registry URL format is https://aws_account_id.dkr.ecr.region.amazonaws.com . For example, https://012345678910.dkr.ecr.us-east-1.amazonaws.com ..
            
            
            
    :type registryIds: list
    """
    pass

def get_download_url_for_layer(registryId=None, repositoryName=None, layerDigest=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the image layer to download. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository that is associated with the image layer to download.
            
    :type repositoryName: string
    :param layerDigest: [REQUIRED]
            The digest of the image layer to download.
            
    :type layerDigest: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_repository_policy(registryId=None, repositoryName=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository whose policy you want to retrieve.
            
    :type repositoryName: string
    """
    pass

def get_waiter():
    """
    """
    pass

def initiate_layer_upload(registryId=None, repositoryName=None):
    """
    :param registryId: The AWS account ID associated with the registry that you intend to upload layers to. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository that you intend to upload layers to.
            
    :type repositoryName: string
    """
    pass

def list_images(registryId=None, repositoryName=None, nextToken=None, maxResults=None, filter=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository to list images in. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The repository whose image IDs are to be listed.
            
    :type repositoryName: string
    :param nextToken: The nextToken value returned from a previous paginated ListImages request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.
            Note
            This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.
            
    :type nextToken: string
    :param maxResults: The maximum number of image results returned by ListImages in paginated output. When this parameter is used, ListImages only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListImages request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListImages returns up to 100 results and a nextToken value, if applicable.
    :type maxResults: integer
    :param filter: The filter key and value with which to filter your ListImages results.
            tagStatus (string) --The tag status with which to filter your ListImages results. You can filter results based on whether they are TAGGED or UNTAGGED .
            
    :type filter: dict
    """
    pass

def put_image(registryId=None, repositoryName=None, imageManifest=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository in which to put the image. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository in which to put the image.
            
    :type repositoryName: string
    :param imageManifest: [REQUIRED]
            The image manifest corresponding to the image to be uploaded.
            
    :type imageManifest: string
    """
    pass

def set_repository_policy(registryId=None, repositoryName=None, policyText=None, force=None):
    """
    :param registryId: The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository to receive the policy.
            
    :type repositoryName: string
    :param policyText: [REQUIRED]
            The JSON repository policy text to apply to the repository.
            
    :type policyText: string
    :param force: If the policy you are attempting to set on a repository policy would prevent you from setting another policy in the future, you must force the SetRepositoryPolicy operation. This is intended to prevent accidental repository lock outs.
    :type force: boolean
    """
    pass

def upload_layer_part(registryId=None, repositoryName=None, uploadId=None, partFirstByte=None, partLastByte=None, layerPartBlob=None):
    """
    :param registryId: The AWS account ID associated with the registry that you are uploading layer parts to. If you do not specify a registry, the default registry is assumed.
    :type registryId: string
    :param repositoryName: [REQUIRED]
            The name of the repository that you are uploading layer parts to.
            
    :type repositoryName: string
    :param uploadId: [REQUIRED]
            The upload ID from a previous InitiateLayerUpload operation to associate with the layer part upload.
            
    :type uploadId: string
    :param partFirstByte: [REQUIRED]
            The integer value of the first byte of the layer part.
            
    :type partFirstByte: integer
    :param partLastByte: [REQUIRED]
            The integer value of the last byte of the layer part.
            
    :type partLastByte: integer
    :param layerPartBlob: [REQUIRED]
            The base64-encoded layer part payload.
            
    :type layerPartBlob: bytes
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def abort_environment_update(EnvironmentId=None, EnvironmentName=None):
    """
    :param EnvironmentId: This specifies the ID of the environment with the in-progress update that you want to cancel.
    :type EnvironmentId: string
    :param EnvironmentName: This specifies the name of the environment with the in-progress update that you want to cancel.
    :type EnvironmentName: string
    """
    pass

def apply_environment_managed_action(EnvironmentName=None, EnvironmentId=None, ActionId=None):
    """
    :param EnvironmentName: The name of the target environment.
    :type EnvironmentName: string
    :param EnvironmentId: The environment ID of the target environment.
    :type EnvironmentId: string
    :param ActionId: [REQUIRED]
            The action ID of the scheduled managed action to execute.
            
    :type ActionId: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def check_dns_availability(CNAMEPrefix=None):
    """
    :param CNAMEPrefix: [REQUIRED]
            The prefix used when this CNAME is reserved.
            Return typedict
            ReturnsResponse Syntax{
              'Available': True|False,
              'FullyQualifiedCNAME': 'string'
            }
            Response Structure
            (dict) --Indicates if the specified CNAME is available.
            Available (boolean) --Indicates if the specified CNAME is available:
            true : The CNAME is available.
            false : The CNAME is not available.
            FullyQualifiedCNAME (string) --The fully qualified CNAME to reserve when CreateEnvironment is called with the provided prefix.
            
            Examples
            The following operation checks the availability of the subdomain my-cname:
            response = client.check_dns_availability(
              CNAMEPrefix='my-cname',
            )
            print(response)
            Expected Output:
            {
              'Available': True,
              'FullyQualifiedCNAME': 'my-cname.us-west-2.elasticbeanstalk.com',
              'ResponseMetadata': {
                '...': '...',
              },
            }
            
    :type CNAMEPrefix: string
    """
    pass

def compose_environments(ApplicationName=None, GroupName=None, VersionLabels=None):
    """
    :param ApplicationName: The name of the application to which the specified source bundles belong.
    :type ApplicationName: string
    :param GroupName: The name of the group to which the target environments belong. Specify a group name only if the environment name defined in each target environment's manifest ends with a + (plus) character. See Environment Manifest (env.yaml) for details.
    :type GroupName: string
    :param VersionLabels: A list of version labels, specifying one or more application source bundles that belong to the target application. Each source bundle must include an environment manifest that specifies the name of the environment and the name of the solution stack to use, and optionally can specify environment links to create.
            (string) --
            
    :type VersionLabels: list
    """
    pass

def create_application(ApplicationName=None, Description=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application.
            Constraint: This name must be unique within your account. If the specified name already exists, the action returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param Description: Describes the application.
    :type Description: string
    """
    pass

def create_application_version(ApplicationName=None, VersionLabel=None, Description=None, SourceBuildInformation=None, SourceBundle=None, AutoCreateApplication=None, Process=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application. If no application is found with this name, and AutoCreateApplication is false , returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param VersionLabel: [REQUIRED]
            A label identifying this version.
            Constraint: Must be unique per application. If an application version already exists with this label for the specified application, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            
    :type VersionLabel: string
    :param Description: Describes this version.
    :type Description: string
    :param SourceBuildInformation: 
            SourceType (string) -- [REQUIRED]
            SourceRepository (string) -- [REQUIRED]
            SourceLocation (string) -- [REQUIRED]
            
    :type SourceBuildInformation: dict
    :param SourceBundle: The Amazon S3 bucket and key that identify the location of the source bundle for this version.
            If data found at the Amazon S3 location exceeds the maximum allowed source bundle size, AWS Elastic Beanstalk returns an InvalidParameterValue error. The maximum size allowed is 512 MB.
            Default: If not specified, AWS Elastic Beanstalk uses a sample application. If only partially specified (for example, a bucket is provided but not the key) or if no data is found at the Amazon S3 location, AWS Elastic Beanstalk returns an InvalidParameterCombination error.
            S3Bucket (string) --The Amazon S3 bucket where the data is located.
            S3Key (string) --The Amazon S3 key where the data is located.
            
    :type SourceBundle: dict
    :param AutoCreateApplication: Determines how the system behaves if the specified application for this version does not already exist:
            true : Automatically creates the specified application for this release if it does not already exist.
            false : Throws an InvalidParameterValue if the specified application for this release does not already exist.
            Default: false
            Valid Values: true | false
            
    :type AutoCreateApplication: boolean
    :param Process: Preprocesses and validates the environment manifest and configuration files in the source bundle. Validating configuration files can identify issues prior to deploying the application version to an environment.
    :type Process: boolean
    """
    pass

def create_configuration_template(ApplicationName=None, TemplateName=None, SolutionStackName=None, SourceConfiguration=None, EnvironmentId=None, Description=None, OptionSettings=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application to associate with this configuration template. If no application is found with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param TemplateName: [REQUIRED]
            The name of the configuration template.
            Constraint: This name must be unique per application.
            Default: If a configuration template already exists with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            
    :type TemplateName: string
    :param SolutionStackName: The name of the solution stack used by this configuration. The solution stack specifies the operating system, architecture, and application server for a configuration template. It determines the set of configuration options as well as the possible and default values.
            Use ListAvailableSolutionStacks to obtain a list of available solution stacks.
            A solution stack name or a source configuration parameter must be specified, otherwise AWS Elastic Beanstalk returns an InvalidParameterValue error.
            If a solution stack name is not specified and the source configuration parameter is specified, AWS Elastic Beanstalk uses the same solution stack as the source configuration template.
            
    :type SolutionStackName: string
    :param SourceConfiguration: If specified, AWS Elastic Beanstalk uses the configuration values from the specified configuration template to create a new configuration.
            Values specified in the OptionSettings parameter of this call overrides any values obtained from the SourceConfiguration .
            If no configuration template is found, returns an InvalidParameterValue error.
            Constraint: If both the solution stack name parameter and the source configuration parameters are specified, the solution stack of the source configuration template must match the specified solution stack name or else AWS Elastic Beanstalk returns an InvalidParameterCombination error.
            ApplicationName (string) --The name of the application associated with the configuration.
            TemplateName (string) --The name of the configuration template.
            
    :type SourceConfiguration: dict
    :param EnvironmentId: The ID of the environment used with this configuration template.
    :type EnvironmentId: string
    :param Description: Describes this configuration.
    :type Description: string
    :param OptionSettings: If specified, AWS Elastic Beanstalk sets the specified configuration option to the requested value. The new value overrides the value obtained from the solution stack or the source configuration template.
            (dict) --A specification identifying an individual configuration option along with its current value. For a list of possible option values, go to Option Values in the AWS Elastic Beanstalk Developer Guide .
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            Value (string) --The current value for the configuration option.
            
            
    :type OptionSettings: list
    """
    pass

def create_environment(ApplicationName=None, EnvironmentName=None, GroupName=None, Description=None, CNAMEPrefix=None, Tier=None, Tags=None, VersionLabel=None, TemplateName=None, SolutionStackName=None, OptionSettings=None, OptionsToRemove=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application that contains the version to be deployed.
            If no application is found with this name, CreateEnvironment returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param EnvironmentName: A unique name for the deployment environment. Used in the application URL.
            Constraint: Must be from 4 to 40 characters in length. The name can contain only letters, numbers, and hyphens. It cannot start or end with a hyphen. This name must be unique in your account. If the specified name already exists, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            Default: If the CNAME parameter is not specified, the environment name becomes part of the CNAME, and therefore part of the visible URL for your application.
            
    :type EnvironmentName: string
    :param GroupName: The name of the group to which the target environment belongs. Specify a group name only if the environment's name is specified in an environment manifest and not with the environment name parameter. See Environment Manifest (env.yaml) for details.
    :type GroupName: string
    :param Description: Describes this environment.
    :type Description: string
    :param CNAMEPrefix: If specified, the environment attempts to use this value as the prefix for the CNAME. If not specified, the CNAME is generated automatically by appending a random alphanumeric string to the environment name.
    :type CNAMEPrefix: string
    :param Tier: This specifies the tier to use for creating this environment.
            Name (string) --The name of this environment tier.
            Type (string) --The type of this environment tier.
            Version (string) --The version of this environment tier.
            
    :type Tier: dict
    :param Tags: This specifies the tags applied to resources in the environment.
            (dict) --Describes a tag applied to a resource in an environment.
            Key (string) --The key of the tag.
            Value (string) --The value of the tag.
            
            
    :type Tags: list
    :param VersionLabel: The name of the application version to deploy.
            If the specified application has no associated application versions, AWS Elastic Beanstalk UpdateEnvironment returns an InvalidParameterValue error.
            Default: If not specified, AWS Elastic Beanstalk attempts to launch the sample application in the container.
            
    :type VersionLabel: string
    :param TemplateName: The name of the configuration template to use in deployment. If no configuration template is found with this name, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            Condition: You must specify either this parameter or a SolutionStackName , but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error.
            
    :type TemplateName: string
    :param SolutionStackName: This is an alternative to specifying a template name. If specified, AWS Elastic Beanstalk sets the configuration values to the default values associated with the specified solution stack.
            Condition: You must specify either this or a TemplateName , but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error.
            
    :type SolutionStackName: string
    :param OptionSettings: If specified, AWS Elastic Beanstalk sets the specified configuration options to the requested value in the configuration set for the new environment. These override the values obtained from the solution stack or the configuration template.
            (dict) --A specification identifying an individual configuration option along with its current value. For a list of possible option values, go to Option Values in the AWS Elastic Beanstalk Developer Guide .
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            Value (string) --The current value for the configuration option.
            
            
    :type OptionSettings: list
    :param OptionsToRemove: A list of custom user-defined configuration options to remove from the configuration set for this new environment.
            (dict) --A specification identifying an individual configuration option.
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            
            
    :type OptionsToRemove: list
    """
    pass

def create_storage_location():
    """
    """
    pass

def delete_application(ApplicationName=None, TerminateEnvByForce=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application to delete.
            
    :type ApplicationName: string
    :param TerminateEnvByForce: When set to true, running environments will be terminated before deleting the application.
    :type TerminateEnvByForce: boolean
    """
    pass

def delete_application_version(ApplicationName=None, VersionLabel=None, DeleteSourceBundle=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application to delete releases from.
            
    :type ApplicationName: string
    :param VersionLabel: [REQUIRED]
            The label of the version to delete.
            
    :type VersionLabel: string
    :param DeleteSourceBundle: Indicates whether to delete the associated source bundle from Amazon S3:
            true : An attempt is made to delete the associated Amazon S3 source bundle specified at time of creation.
            false : No action is taken on the Amazon S3 source bundle specified at time of creation.
            Valid Values: true | false
            
    :type DeleteSourceBundle: boolean
    """
    pass

def delete_configuration_template(ApplicationName=None, TemplateName=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application to delete the configuration template from.
            
    :type ApplicationName: string
    :param TemplateName: [REQUIRED]
            The name of the configuration template to delete.
            
    :type TemplateName: string
    """
    pass

def delete_environment_configuration(ApplicationName=None, EnvironmentName=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application the environment is associated with.
            
    :type ApplicationName: string
    :param EnvironmentName: [REQUIRED]
            The name of the environment to delete the draft configuration from.
            
    :type EnvironmentName: string
    """
    pass

def describe_application_versions(ApplicationName=None, VersionLabels=None, MaxRecords=None, NextToken=None):
    """
    :param ApplicationName: If specified, AWS Elastic Beanstalk restricts the returned descriptions to only include ones that are associated with the specified application.
    :type ApplicationName: string
    :param VersionLabels: If specified, restricts the returned descriptions to only include ones that have the specified version labels.
            (string) --
            
    :type VersionLabels: list
    :param MaxRecords: Specify a maximum number of application versions to paginate in the request.
    :type MaxRecords: integer
    :param NextToken: Specify a next token to retrieve the next page in a paginated request.
    :type NextToken: string
    """
    pass

def describe_applications(ApplicationNames=None):
    """
    :param ApplicationNames: If specified, AWS Elastic Beanstalk restricts the returned descriptions to only include those with the specified names.
            (string) --
            Return typedict
            ReturnsResponse Syntax{
              'Applications': [
                {
                  'ApplicationName': 'string',
                  'Description': 'string',
                  'DateCreated': datetime(2015, 1, 1),
                  'DateUpdated': datetime(2015, 1, 1),
                  'Versions': [
                    'string',
                  ],
                  'ConfigurationTemplates': [
                    'string',
                  ]
                },
              ]
            }
            Response Structure
            (dict) --Result message containing a list of application descriptions.
            Applications (list) --This parameter contains a list of ApplicationDescription .
            (dict) --Describes the properties of an application.
            ApplicationName (string) --The name of the application.
            Description (string) --User-defined description of the application.
            DateCreated (datetime) --The date when the application was created.
            DateUpdated (datetime) --The date when the application was last modified.
            Versions (list) --The names of the versions for this application.
            (string) --
            ConfigurationTemplates (list) --The names of the configuration templates associated with this application.
            (string) --
            
            
            Examples
            The following operation retrieves information about applications in the current region:
            response = client.describe_applications(
            )
            print(response)
            Expected Output:
            {
              'Applications': [
                {
                  'ApplicationName': 'ruby',
                  'ConfigurationTemplates': [
                  ],
                  'DateCreated': datetime(2015, 8, 13, 21, 5, 44, 3, 225, 0),
                  'DateUpdated': datetime(2015, 8, 13, 21, 5, 44, 3, 225, 0),
                  'Versions': [
                    'Sample Application',
                  ],
                },
                {
                  'ApplicationName': 'pythonsample',
                  'ConfigurationTemplates': [
                  ],
                  'DateCreated': datetime(2015, 8, 13, 19, 5, 43, 3, 225, 0),
                  'DateUpdated': datetime(2015, 8, 13, 19, 5, 43, 3, 225, 0),
                  'Description': 'Application created from the EB CLI using 'eb init'',
                  'Versions': [
                    'Sample Application',
                  ],
                },
                {
                  'ApplicationName': 'nodejs-example',
                  'ConfigurationTemplates': [
                  ],
                  'DateCreated': datetime(2015, 8, 6, 17, 50, 2, 3, 218, 0),
                  'DateUpdated': datetime(2015, 8, 6, 17, 50, 2, 3, 218, 0),
                  'Versions': [
                    'add elasticache',
                    'First Release',
                  ],
                },
              ],
              'ResponseMetadata': {
                '...': '...',
              },
            }
            
    :type ApplicationNames: list
    """
    pass

def describe_configuration_options(ApplicationName=None, TemplateName=None, EnvironmentName=None, SolutionStackName=None, Options=None):
    """
    :param ApplicationName: The name of the application associated with the configuration template or environment. Only needed if you want to describe the configuration options associated with either the configuration template or environment.
    :type ApplicationName: string
    :param TemplateName: The name of the configuration template whose configuration options you want to describe.
    :type TemplateName: string
    :param EnvironmentName: The name of the environment whose configuration options you want to describe.
    :type EnvironmentName: string
    :param SolutionStackName: The name of the solution stack whose configuration options you want to describe.
    :type SolutionStackName: string
    :param Options: If specified, restricts the descriptions to only the specified options.
            (dict) --A specification identifying an individual configuration option.
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            
            
    :type Options: list
    """
    pass

def describe_configuration_settings(ApplicationName=None, TemplateName=None, EnvironmentName=None):
    """
    :param ApplicationName: [REQUIRED]
            The application for the environment or configuration template.
            
    :type ApplicationName: string
    :param TemplateName: The name of the configuration template to describe.
            Conditional: You must specify either this parameter or an EnvironmentName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns a MissingRequiredParameter error.
            
    :type TemplateName: string
    :param EnvironmentName: The name of the environment to describe.
            Condition: You must specify either this or a TemplateName, but not both. If you specify both, AWS Elastic Beanstalk returns an InvalidParameterCombination error. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    """
    pass

def describe_environment_health(EnvironmentName=None, EnvironmentId=None, AttributeNames=None):
    """
    :param EnvironmentName: Specifies the AWS Elastic Beanstalk environment name.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    :param EnvironmentId: Specifies the AWS Elastic Beanstalk environment ID.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param AttributeNames: Specifies the response elements you wish to receive. If no attribute names are specified, AWS Elastic Beanstalk only returns the name of the environment.
            (string) --
            
    :type AttributeNames: list
    """
    pass

def describe_environment_managed_action_history(EnvironmentId=None, EnvironmentName=None, NextToken=None, MaxItems=None):
    """
    :param EnvironmentId: The environment ID of the target environment.
    :type EnvironmentId: string
    :param EnvironmentName: The name of the target environment.
    :type EnvironmentName: string
    :param NextToken: The pagination token returned by a previous request.
    :type NextToken: string
    :param MaxItems: The maximum number of items to return for a single request.
    :type MaxItems: integer
    """
    pass

def describe_environment_managed_actions(EnvironmentName=None, EnvironmentId=None, Status=None):
    """
    :param EnvironmentName: The name of the target environment.
    :type EnvironmentName: string
    :param EnvironmentId: The environment ID of the target environment.
    :type EnvironmentId: string
    :param Status: To show only actions with a particular status, specify a status.
    :type Status: string
    """
    pass

def describe_environment_resources(EnvironmentId=None, EnvironmentName=None):
    """
    :param EnvironmentId: The ID of the environment to retrieve AWS resource usage data.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment to retrieve AWS resource usage data.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    """
    pass

def describe_environments(ApplicationName=None, VersionLabel=None, EnvironmentIds=None, EnvironmentNames=None, IncludeDeleted=None, IncludedDeletedBackTo=None):
    """
    :param ApplicationName: If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application.
    :type ApplicationName: string
    :param VersionLabel: If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that are associated with this application version.
    :type VersionLabel: string
    :param EnvironmentIds: If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified IDs.
            (string) --
            
    :type EnvironmentIds: list
    :param EnvironmentNames: If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those that have the specified names.
            (string) --
            
    :type EnvironmentNames: list
    :param IncludeDeleted: Indicates whether to include deleted environments:
            true : Environments that have been deleted after IncludedDeletedBackTo are displayed.false : Do not include deleted environments.
            
    :type IncludeDeleted: boolean
    :param IncludedDeletedBackTo: If specified when IncludeDeleted is set to true , then environments deleted after this date are displayed.
    :type IncludedDeletedBackTo: datetime
    """
    pass

def describe_events(ApplicationName=None, VersionLabel=None, TemplateName=None, EnvironmentId=None, EnvironmentName=None, RequestId=None, Severity=None, StartTime=None, EndTime=None, MaxRecords=None, NextToken=None):
    """
    :param ApplicationName: If specified, AWS Elastic Beanstalk restricts the returned descriptions to include only those associated with this application.
    :type ApplicationName: string
    :param VersionLabel: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this application version.
    :type VersionLabel: string
    :param TemplateName: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that are associated with this environment configuration.
    :type TemplateName: string
    :param EnvironmentId: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
    :type EnvironmentId: string
    :param EnvironmentName: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those associated with this environment.
    :type EnvironmentName: string
    :param RequestId: If specified, AWS Elastic Beanstalk restricts the described events to include only those associated with this request ID.
    :type RequestId: string
    :param Severity: If specified, limits the events returned from this call to include only those with the specified severity or higher.
    :type Severity: string
    :param StartTime: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur on or after this time.
    :type StartTime: datetime
    :param EndTime: If specified, AWS Elastic Beanstalk restricts the returned descriptions to those that occur up to, but not including, the EndTime .
    :type EndTime: datetime
    :param MaxRecords: Specifies the maximum number of events that can be returned, beginning with the most recent event.
    :type MaxRecords: integer
    :param NextToken: Pagination token. If specified, the events return the next batch of results.
    :type NextToken: string
    """
    pass

def describe_instances_health(EnvironmentName=None, EnvironmentId=None, AttributeNames=None, NextToken=None):
    """
    :param EnvironmentName: Specifies the AWS Elastic Beanstalk environment name.
    :type EnvironmentName: string
    :param EnvironmentId: Specifies the AWS Elastic Beanstalk environment ID.
    :type EnvironmentId: string
    :param AttributeNames: Specifies the response elements you wish to receive. If no attribute names are specified, AWS Elastic Beanstalk only returns a list of instances.
            (string) --
            
    :type AttributeNames: list
    :param NextToken: Specifies the next token of the request.
    :type NextToken: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_available_solution_stacks():
    """
    """
    pass

def rebuild_environment(EnvironmentId=None, EnvironmentName=None):
    """
    :param EnvironmentId: The ID of the environment to rebuild.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment to rebuild.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    """
    pass

def request_environment_info(EnvironmentId=None, EnvironmentName=None, InfoType=None):
    """
    :param EnvironmentId: The ID of the environment of the requested data.
            If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment of the requested data.
            If no such environment is found, RequestEnvironmentInfo returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    :param InfoType: [REQUIRED]
            The type of information to request.
            
    :type InfoType: string
    """
    pass

def restart_app_server(EnvironmentId=None, EnvironmentName=None):
    """
    :param EnvironmentId: The ID of the environment to restart the server for.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment to restart the server for.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    """
    pass

def retrieve_environment_info(EnvironmentId=None, EnvironmentName=None, InfoType=None):
    """
    :param EnvironmentId: The ID of the data's environment.
            If no such environment is found, returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the data's environment.
            If no such environment is found, returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    :param InfoType: [REQUIRED]
            The type of information to retrieve.
            
    :type InfoType: string
    """
    pass

def swap_environment_cnames(SourceEnvironmentId=None, SourceEnvironmentName=None, DestinationEnvironmentId=None, DestinationEnvironmentName=None):
    """
    :param SourceEnvironmentId: The ID of the source environment.
            Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName . You may also specify both. If you specify the SourceEnvironmentId , you must specify the DestinationEnvironmentId .
            
    :type SourceEnvironmentId: string
    :param SourceEnvironmentName: The name of the source environment.
            Condition: You must specify at least the SourceEnvironmentID or the SourceEnvironmentName . You may also specify both. If you specify the SourceEnvironmentName , you must specify the DestinationEnvironmentName .
            
    :type SourceEnvironmentName: string
    :param DestinationEnvironmentId: The ID of the destination environment.
            Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName . You may also specify both. You must specify the SourceEnvironmentId with the DestinationEnvironmentId .
            
    :type DestinationEnvironmentId: string
    :param DestinationEnvironmentName: The name of the destination environment.
            Condition: You must specify at least the DestinationEnvironmentID or the DestinationEnvironmentName . You may also specify both. You must specify the SourceEnvironmentName with the DestinationEnvironmentName .
            
    :type DestinationEnvironmentName: string
    """
    pass

def terminate_environment(EnvironmentId=None, EnvironmentName=None, TerminateResources=None, ForceTerminate=None):
    """
    :param EnvironmentId: The ID of the environment to terminate.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment to terminate.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    :param TerminateResources: Indicates whether the associated AWS resources should shut down when the environment is terminated:
            true : The specified environment as well as the associated AWS resources, such as Auto Scaling group and LoadBalancer, are terminated.
            false : AWS Elastic Beanstalk resource management is removed from the environment, but the AWS resources continue to operate.
            For more information, see the AWS Elastic Beanstalk User Guide.
            Default: true
            Valid Values: true | false
            
    :type TerminateResources: boolean
    :param ForceTerminate: Terminates the target environment even if another environment in the same group is dependent on it.
    :type ForceTerminate: boolean
    """
    pass

def update_application(ApplicationName=None, Description=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application to update. If no such application is found, UpdateApplication returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param Description: A new description for the application.
            Default: If not specified, AWS Elastic Beanstalk does not update the description.
            
    :type Description: string
    """
    pass

def update_application_version(ApplicationName=None, VersionLabel=None, Description=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application associated with this version.
            If no application is found with this name, UpdateApplication returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param VersionLabel: [REQUIRED]
            The name of the version to update.
            If no application version is found with this label, UpdateApplication returns an InvalidParameterValue error.
            
    :type VersionLabel: string
    :param Description: A new description for this release.
    :type Description: string
    """
    pass

def update_configuration_template(ApplicationName=None, TemplateName=None, Description=None, OptionSettings=None, OptionsToRemove=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application associated with the configuration template to update.
            If no application is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error.
            
    :type ApplicationName: string
    :param TemplateName: [REQUIRED]
            The name of the configuration template to update.
            If no configuration template is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error.
            
    :type TemplateName: string
    :param Description: A new description for the configuration.
    :type Description: string
    :param OptionSettings: A list of configuration option settings to update with the new specified option value.
            (dict) --A specification identifying an individual configuration option along with its current value. For a list of possible option values, go to Option Values in the AWS Elastic Beanstalk Developer Guide .
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            Value (string) --The current value for the configuration option.
            
            
    :type OptionSettings: list
    :param OptionsToRemove: A list of configuration options to remove from the configuration set.
            Constraint: You can remove only UserDefined configuration options.
            (dict) --A specification identifying an individual configuration option.
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            
            
    :type OptionsToRemove: list
    """
    pass

def update_environment(ApplicationName=None, EnvironmentId=None, EnvironmentName=None, GroupName=None, Description=None, Tier=None, VersionLabel=None, TemplateName=None, SolutionStackName=None, OptionSettings=None, OptionsToRemove=None):
    """
    :param ApplicationName: The name of the application with which the environment is associated.
    :type ApplicationName: string
    :param EnvironmentId: The ID of the environment to update.
            If no environment with this ID exists, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentId: string
    :param EnvironmentName: The name of the environment to update. If no environment with this name exists, AWS Elastic Beanstalk returns an InvalidParameterValue error.
            Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error.
            
    :type EnvironmentName: string
    :param GroupName: The name of the group to which the target environment belongs. Specify a group name only if the environment's name is specified in an environment manifest and not with the environment name or environment ID parameters. See Environment Manifest (env.yaml) for details.
    :type GroupName: string
    :param Description: If this parameter is specified, AWS Elastic Beanstalk updates the description of this environment.
    :type Description: string
    :param Tier: This specifies the tier to use to update the environment.
            Condition: At this time, if you change the tier version, name, or type, AWS Elastic Beanstalk returns InvalidParameterValue error.
            Name (string) --The name of this environment tier.
            Type (string) --The type of this environment tier.
            Version (string) --The version of this environment tier.
            
    :type Tier: dict
    :param VersionLabel: If this parameter is specified, AWS Elastic Beanstalk deploys the named application version to the environment. If no such application version is found, returns an InvalidParameterValue error.
    :type VersionLabel: string
    :param TemplateName: If this parameter is specified, AWS Elastic Beanstalk deploys this configuration template to the environment. If no such configuration template is found, AWS Elastic Beanstalk returns an InvalidParameterValue error.
    :type TemplateName: string
    :param SolutionStackName: This specifies the platform version that the environment will run after the environment is updated.
    :type SolutionStackName: string
    :param OptionSettings: If specified, AWS Elastic Beanstalk updates the configuration set associated with the running environment and sets the specified configuration options to the requested value.
            (dict) --A specification identifying an individual configuration option along with its current value. For a list of possible option values, go to Option Values in the AWS Elastic Beanstalk Developer Guide .
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            Value (string) --The current value for the configuration option.
            
            
    :type OptionSettings: list
    :param OptionsToRemove: A list of custom user-defined configuration options to remove from the configuration set for this environment.
            (dict) --A specification identifying an individual configuration option.
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            
            
    :type OptionsToRemove: list
    """
    pass

def validate_configuration_settings(ApplicationName=None, TemplateName=None, EnvironmentName=None, OptionSettings=None):
    """
    :param ApplicationName: [REQUIRED]
            The name of the application that the configuration template or environment belongs to.
            
    :type ApplicationName: string
    :param TemplateName: The name of the configuration template to validate the settings against.
            Condition: You cannot specify both this and an environment name.
            
    :type TemplateName: string
    :param EnvironmentName: The name of the environment to validate the settings against.
            Condition: You cannot specify both this and a configuration template name.
            
    :type EnvironmentName: string
    :param OptionSettings: [REQUIRED]
            A list of the options and desired values to evaluate.
            (dict) --A specification identifying an individual configuration option along with its current value. For a list of possible option values, go to Option Values in the AWS Elastic Beanstalk Developer Guide .
            ResourceName (string) --A unique resource name for a time-based scaling configuration option.
            Namespace (string) --A unique namespace identifying the option's associated AWS resource.
            OptionName (string) --The name of the configuration option.
            Value (string) --The current value for the configuration option.
            
            
    :type OptionSettings: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def delete_rule(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the rule to be deleted.
            ReturnsNone
            
    :type Name: string
    """
    pass

def describe_rule(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the rule you want to describe details for.
            Return typedict
            ReturnsResponse Syntax{
              'Name': 'string',
              'Arn': 'string',
              'EventPattern': 'string',
              'ScheduleExpression': 'string',
              'State': 'ENABLED'|'DISABLED',
              'Description': 'string',
              'RoleArn': 'string'
            }
            Response Structure
            (dict) --The result of the DescribeRule operation.
            Name (string) --The rule's name.
            Arn (string) --The Amazon Resource Name (ARN) associated with the rule.
            EventPattern (string) --The event pattern.
            ScheduleExpression (string) --The scheduling expression. For example, 'cron(0 20 * * ? *)', 'rate(5 minutes)'.
            State (string) --Specifies whether the rule is enabled or disabled.
            Description (string) --The rule's description.
            RoleArn (string) --The Amazon Resource Name (ARN) of the IAM role associated with the rule.
            
            
    :type Name: string
    """
    pass

def disable_rule(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the rule you want to disable.
            ReturnsNone
            
    :type Name: string
    """
    pass

def enable_rule(Name=None):
    """
    :param Name: [REQUIRED]
            The name of the rule that you want to enable.
            ReturnsNone
            
    :type Name: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_rule_names_by_target(TargetArn=None, NextToken=None, Limit=None):
    """
    :param TargetArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the target resource that you want to list the rules for.
            
    :type TargetArn: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    :param Limit: The maximum number of results to return.
    :type Limit: integer
    """
    pass

def list_rules(NamePrefix=None, NextToken=None, Limit=None):
    """
    :param NamePrefix: The prefix matching the rule name.
    :type NamePrefix: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    :param Limit: The maximum number of results to return.
    :type Limit: integer
    """
    pass

def list_targets_by_rule(Rule=None, NextToken=None, Limit=None):
    """
    :param Rule: [REQUIRED]
            The name of the rule whose targets you want to list.
            
    :type Rule: string
    :param NextToken: The token returned by a previous call to indicate that there is more data available.
    :type NextToken: string
    :param Limit: The maximum number of results to return.
    :type Limit: integer
    """
    pass

def put_events(Entries=None):
    """
    :param Entries: [REQUIRED]
            The entry that defines an event in your system. You can specify several parameters for the entry such as the source and type of the event, resources associated with the event, and so on.
            (dict) --Contains information about the event to be used in PutEvents.
            Time (datetime) --Timestamp of event, per RFC3339 . If no timestamp is provided, the timestamp of the PutEvents call will be used.
            Source (string) --The source of the event.
            Resources (list) --AWS resources, identified by Amazon Resource Name (ARN), which the event primarily concerns. Any number, including zero, may be present.
            (string) --
            DetailType (string) --Free-form string used to decide what fields to expect in the event detail.
            Detail (string) --In the JSON sense, an object containing fields, which may also contain nested sub-objects. No constraints are imposed on its contents.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedEntryCount': 123,
              'Entries': [
                {
                  'EventId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --The result of the PutEvents operation.
            FailedEntryCount (integer) --The number of failed entries.
            Entries (list) --A list of successfully and unsuccessfully ingested events results. If the ingestion was successful, the entry will have the event ID in it. If not, then the ErrorCode and ErrorMessage can be used to identify the problem with the entry.
            (dict) --A PutEventsResult contains a list of PutEventsResultEntry.
            EventId (string) --The ID of the event submitted to Amazon CloudWatch Events.
            ErrorCode (string) --The error code representing why the event submission failed on this entry.
            ErrorMessage (string) --The error message explaining why the event submission failed on this entry.
            
            
            
    :type Entries: list
    """
    pass

def put_rule(Name=None, ScheduleExpression=None, EventPattern=None, State=None, Description=None, RoleArn=None):
    """
    :param Name: [REQUIRED]
            The name of the rule that you are creating or updating.
            
    :type Name: string
    :param ScheduleExpression: The scheduling expression. For example, 'cron(0 20 * * ? *)', 'rate(5 minutes)'.
    :type ScheduleExpression: string
    :param EventPattern: The event pattern.
    :type EventPattern: string
    :param State: Indicates whether the rule is enabled or disabled.
    :type State: string
    :param Description: A description of the rule.
    :type Description: string
    :param RoleArn: The Amazon Resource Name (ARN) of the IAM role associated with the rule.
    :type RoleArn: string
    """
    pass

def put_targets(Rule=None, Targets=None):
    """
    :param Rule: [REQUIRED]
            The name of the rule you want to add targets to.
            
    :type Rule: string
    :param Targets: [REQUIRED]
            List of targets you want to update or add to the rule.
            (dict) --Targets are the resources that can be invoked when a rule is triggered. For example, AWS Lambda functions, Amazon Kinesis streams, and built-in targets.
            Input and InputPath are mutually-exclusive and optional parameters of a target. When a rule is triggered due to a matched event, if for a target:
            Neither Input nor InputPath is specified, then the entire event is passed to the target in JSON form.
            InputPath is specified in the form of JSONPath (e.g. $.detail ), then only the part of the event specified in the path is passed to the target (e.g. only the detail part of the event is passed).
            Input is specified in the form of a valid JSON, then the matched event is overridden with this constant.
            Id (string) -- [REQUIRED]The unique target assignment ID.
            Arn (string) -- [REQUIRED]The Amazon Resource Name (ARN) associated of the target.
            Input (string) --Valid JSON text passed to the target. For more information about JSON text, see The JavaScript Object Notation (JSON) Data Interchange Format .
            InputPath (string) --The value of the JSONPath that is used for extracting part of the matched event when passing it to the target. For more information about JSON paths, see JSONPath .
            
            
    :type Targets: list
    """
    pass

def remove_targets(Rule=None, Ids=None):
    """
    :param Rule: [REQUIRED]
            The name of the rule you want to remove targets from.
            
    :type Rule: string
    :param Ids: [REQUIRED]
            The list of target IDs to remove from the rule.
            (string) --
            
    :type Ids: list
    """
    pass

def test_event_pattern(EventPattern=None, Event=None):
    """
    :param EventPattern: [REQUIRED]
            The event pattern you want to test.
            
    :type EventPattern: string
    :param Event: [REQUIRED]
            The event in the JSON format to test against the event pattern.
            
    :type Event: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_ip_routes(DirectoryId=None, IpRoutes=None, UpdateSecurityGroupForDirectoryControllers=None):
    """
    :param DirectoryId: [REQUIRED]
            Identifier (ID) of the directory to which to add the address block.
            
    :type DirectoryId: string
    :param IpRoutes: [REQUIRED]
            IP address blocks, using CIDR format, of the traffic to route. This is often the IP address block of the DNS server used for your on-premises domain.
            (dict) --IP address block. This is often the address block of the DNS server used for your on-premises domain.
            CidrIp (string) --IP address block using CIDR format, for example 10.0.0.0/24. This is often the address block of the DNS server used for your on-premises domain. For a single IP address use a CIDR address block with /32. For example 10.0.0.0/32.
            Description (string) --Description of the address block.
            
            
    :type IpRoutes: list
    :param UpdateSecurityGroupForDirectoryControllers: If set to true, updates the inbound and outbound rules of the security group that has the description: 'AWS created security group for directory ID directory controllers.' Following are the new rules:
            Inbound:
            Type: Custom UDP Rule, Protocol: UDP, Range: 88, Source: 0.0.0.0/0
            Type: Custom UDP Rule, Protocol: UDP, Range: 123, Source: 0.0.0.0/0
            Type: Custom UDP Rule, Protocol: UDP, Range: 138, Source: 0.0.0.0/0
            Type: Custom UDP Rule, Protocol: UDP, Range: 389, Source: 0.0.0.0/0
            Type: Custom UDP Rule, Protocol: UDP, Range: 464, Source: 0.0.0.0/0
            Type: Custom UDP Rule, Protocol: UDP, Range: 445, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 88, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 135, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 445, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 464, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 636, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 1024-65535, Source: 0.0.0.0/0
            Type: Custom TCP Rule, Protocol: TCP, Range: 3268-33269, Source: 0.0.0.0/0
            Type: DNS (UDP), Protocol: UDP, Range: 53, Source: 0.0.0.0/0
            Type: DNS (TCP), Protocol: TCP, Range: 53, Source: 0.0.0.0/0
            Type: LDAP, Protocol: TCP, Range: 389, Source: 0.0.0.0/0
            Type: All ICMP, Protocol: All, Range: N/A, Source: 0.0.0.0/0
            Outbound:
            Type: All traffic, Protocol: All, Range: All, Destination: 0.0.0.0/0
            These security rules impact an internal network interface that is not exposed publicly.
            
    :type UpdateSecurityGroupForDirectoryControllers: boolean
    """
    pass

def add_tags_to_resource(ResourceId=None, Tags=None):
    """
    :param ResourceId: [REQUIRED]
            Identifier (ID) for the directory to which to add the tag.
            
    :type ResourceId: string
    :param Tags: [REQUIRED]
            The tags to be assigned to the Amazon Directory Services directory.
            (dict) --Metadata assigned to an Amazon Directory Services directory consisting of a key-value pair.
            Key (string) -- [REQUIRED]Required name of the tag. The string value can be Unicode characters and cannot be prefixed with 'aws:'. The string can contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            Value (string) -- [REQUIRED]The optional value of the tag. The string value can be Unicode characters. The string can contain only the set of Unicode letters, digits, white-space, '_', '.', '/', '=', '+', '-' (Java regex: '^([\p{L}\p{Z}\p{N}_.:/=+\-]*)$').
            
            
    :type Tags: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def connect_directory(Name=None, ShortName=None, Password=None, Description=None, Size=None, ConnectSettings=None):
    """
    :param Name: [REQUIRED]
            The fully-qualified name of the on-premises directory, such as corp.example.com .
            
    :type Name: string
    :param ShortName: The NetBIOS name of the on-premises directory, such as CORP .
    :type ShortName: string
    :param Password: [REQUIRED]
            The password for the on-premises user account.
            
    :type Password: string
    :param Description: A textual description for the directory.
    :type Description: string
    :param Size: [REQUIRED]
            The size of the directory.
            
    :type Size: string
    :param ConnectSettings: [REQUIRED]
            A DirectoryConnectSettings object that contains additional information for the operation.
            VpcId (string) -- [REQUIRED]The identifier of the VPC in which the AD Connector is created.
            SubnetIds (list) -- [REQUIRED]A list of subnet identifiers in the VPC in which the AD Connector is created.
            (string) --
            CustomerDnsIps (list) -- [REQUIRED]A list of one or more IP addresses of DNS servers or domain controllers in the on-premises directory.
            (string) --
            CustomerUserName (string) -- [REQUIRED]The username of an account in the on-premises directory that is used to connect to the directory. This account must have the following privileges:
            Read users and groups
            Create computer objects
            Join computers to the domain
            
    :type ConnectSettings: dict
    """
    pass

def create_alias(DirectoryId=None, Alias=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to create the alias.
            
    :type DirectoryId: string
    :param Alias: [REQUIRED]
            The requested alias.
            The alias must be unique amongst all aliases in AWS. This operation throws an EntityAlreadyExistsException error if the alias already exists.
            
    :type Alias: string
    """
    pass

def create_computer(DirectoryId=None, ComputerName=None, Password=None, OrganizationalUnitDistinguishedName=None, ComputerAttributes=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory in which to create the computer account.
            
    :type DirectoryId: string
    :param ComputerName: [REQUIRED]
            The name of the computer account.
            
    :type ComputerName: string
    :param Password: [REQUIRED]
            A one-time password that is used to join the computer to the directory. You should generate a random, strong password to use for this parameter.
            
    :type Password: string
    :param OrganizationalUnitDistinguishedName: The fully-qualified distinguished name of the organizational unit to place the computer account in.
    :type OrganizationalUnitDistinguishedName: string
    :param ComputerAttributes: An array of Attribute objects that contain any LDAP attributes to apply to the computer account.
            (dict) --Represents a named directory attribute.
            Name (string) --The name of the attribute.
            Value (string) --The value of the attribute.
            
            
    :type ComputerAttributes: list
    """
    pass

def create_conditional_forwarder(DirectoryId=None, RemoteDomainName=None, DnsIpAddrs=None):
    """
    :param DirectoryId: [REQUIRED]
            The directory ID of the AWS directory for which you are creating the conditional forwarder.
            
    :type DirectoryId: string
    :param RemoteDomainName: [REQUIRED]
            The fully qualified domain name (FQDN) of the remote domain with which you will set up a trust relationship.
            
    :type RemoteDomainName: string
    :param DnsIpAddrs: [REQUIRED]
            The IP addresses of the remote DNS server associated with RemoteDomainName.
            (string) --
            
    :type DnsIpAddrs: list
    """
    pass

def create_directory(Name=None, ShortName=None, Password=None, Description=None, Size=None, VpcSettings=None):
    """
    :param Name: [REQUIRED]
            The fully qualified name for the directory, such as corp.example.com .
            
    :type Name: string
    :param ShortName: The short name of the directory, such as CORP .
    :type ShortName: string
    :param Password: [REQUIRED]
            The password for the directory administrator. The directory creation process creates a directory administrator account with the username Administrator and this password.
            
    :type Password: string
    :param Description: A textual description for the directory.
    :type Description: string
    :param Size: [REQUIRED]
            The size of the directory.
            
    :type Size: string
    :param VpcSettings: A DirectoryVpcSettings object that contains additional information for the operation.
            VpcId (string) -- [REQUIRED]The identifier of the VPC in which to create the directory.
            SubnetIds (list) -- [REQUIRED]The identifiers of the subnets for the directory servers. The two subnets must be in different Availability Zones. AWS Directory Service creates a directory server and a DNS server in each of these subnets.
            (string) --
            
    :type VpcSettings: dict
    """
    pass

def create_microsoft_ad(Name=None, ShortName=None, Password=None, Description=None, VpcSettings=None):
    """
    :param Name: [REQUIRED]
            The fully qualified domain name for the directory, such as corp.example.com . This name will resolve inside your VPC only. It does not need to be publicly resolvable.
            
    :type Name: string
    :param ShortName: The NetBIOS name for your domain. A short identifier for your domain, such as CORP . If you don't specify a NetBIOS name, it will default to the first part of your directory DNS. For example, CORP for the directory DNS corp.example.com .
    :type ShortName: string
    :param Password: [REQUIRED]
            The password for the default administrative user named Admin .
            
    :type Password: string
    :param Description: A textual description for the directory. This label will appear on the AWS console Directory Details page after the directory is created.
    :type Description: string
    :param VpcSettings: [REQUIRED]
            Contains VPC information for the CreateDirectory or CreateMicrosoftAD operation.
            VpcId (string) -- [REQUIRED]The identifier of the VPC in which to create the directory.
            SubnetIds (list) -- [REQUIRED]The identifiers of the subnets for the directory servers. The two subnets must be in different Availability Zones. AWS Directory Service creates a directory server and a DNS server in each of these subnets.
            (string) --
            
    :type VpcSettings: dict
    """
    pass

def create_snapshot(DirectoryId=None, Name=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory of which to take a snapshot.
            
    :type DirectoryId: string
    :param Name: The descriptive name to apply to the snapshot.
    :type Name: string
    """
    pass

def create_trust(DirectoryId=None, RemoteDomainName=None, TrustPassword=None, TrustDirection=None, TrustType=None, ConditionalForwarderIpAddrs=None):
    """
    :param DirectoryId: [REQUIRED]
            The Directory ID of the Microsoft AD in the AWS cloud for which to establish the trust relationship.
            
    :type DirectoryId: string
    :param RemoteDomainName: [REQUIRED]
            The Fully Qualified Domain Name (FQDN) of the external domain for which to create the trust relationship.
            
    :type RemoteDomainName: string
    :param TrustPassword: [REQUIRED]
            The trust password. The must be the same password that was used when creating the trust relationship on the external domain.
            
    :type TrustPassword: string
    :param TrustDirection: [REQUIRED]
            The direction of the trust relationship.
            
    :type TrustDirection: string
    :param TrustType: The trust relationship type.
    :type TrustType: string
    :param ConditionalForwarderIpAddrs: The IP addresses of the remote DNS server associated with RemoteDomainName.
            (string) --
            
    :type ConditionalForwarderIpAddrs: list
    """
    pass

def delete_conditional_forwarder(DirectoryId=None, RemoteDomainName=None):
    """
    :param DirectoryId: [REQUIRED]
            The directory ID for which you are deleting the conditional forwarder.
            
    :type DirectoryId: string
    :param RemoteDomainName: [REQUIRED]
            The fully qualified domain name (FQDN) of the remote domain with which you are deleting the conditional forwarder.
            
    :type RemoteDomainName: string
    """
    pass

def delete_directory(DirectoryId=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory to delete.
            Return typedict
            ReturnsResponse Syntax{
              'DirectoryId': 'string'
            }
            Response Structure
            (dict) --Contains the results of the DeleteDirectory operation.
            DirectoryId (string) --The directory identifier.
            
            
    :type DirectoryId: string
    """
    pass

def delete_snapshot(SnapshotId=None):
    """
    :param SnapshotId: [REQUIRED]
            The identifier of the directory snapshot to be deleted.
            Return typedict
            ReturnsResponse Syntax{
              'SnapshotId': 'string'
            }
            Response Structure
            (dict) --Contains the results of the DeleteSnapshot operation.
            SnapshotId (string) --The identifier of the directory snapshot that was deleted.
            
            
    :type SnapshotId: string
    """
    pass

def delete_trust(TrustId=None, DeleteAssociatedConditionalForwarder=None):
    """
    :param TrustId: [REQUIRED]
            The Trust ID of the trust relationship to be deleted.
            
    :type TrustId: string
    :param DeleteAssociatedConditionalForwarder: Delete a conditional forwarder as part of a DeleteTrustRequest.
    :type DeleteAssociatedConditionalForwarder: boolean
    """
    pass

def deregister_event_topic(DirectoryId=None, TopicName=None):
    """
    :param DirectoryId: [REQUIRED]
            The Directory ID to remove as a publisher. This directory will no longer send messages to the specified SNS topic.
            
    :type DirectoryId: string
    :param TopicName: [REQUIRED]
            The name of the SNS topic from which to remove the directory as a publisher.
            
    :type TopicName: string
    """
    pass

def describe_conditional_forwarders(DirectoryId=None, RemoteDomainNames=None):
    """
    :param DirectoryId: [REQUIRED]
            The directory ID for which to get the list of associated conditional forwarders.
            
    :type DirectoryId: string
    :param RemoteDomainNames: The fully qualified domain names (FQDN) of the remote domains for which to get the list of associated conditional forwarders. If this member is null, all conditional forwarders are returned.
            (string) --
            
    :type RemoteDomainNames: list
    """
    pass

def describe_directories(DirectoryIds=None, NextToken=None, Limit=None):
    """
    :param DirectoryIds: A list of identifiers of the directories for which to obtain the information. If this member is null, all directories that belong to the current account are returned.
            An empty list results in an InvalidParameterException being thrown.
            (string) --
            
    :type DirectoryIds: list
    :param NextToken: The DescribeDirectoriesResult.NextToken value from a previous call to DescribeDirectories . Pass null if this is the first call.
    :type NextToken: string
    :param Limit: The maximum number of items to return. If this value is zero, the maximum number of items is specified by the limitations of the operation.
    :type Limit: integer
    """
    pass

def describe_event_topics(DirectoryId=None, TopicNames=None):
    """
    :param DirectoryId: The Directory ID for which to get the list of associated SNS topics. If this member is null, associations for all Directory IDs are returned.
    :type DirectoryId: string
    :param TopicNames: A list of SNS topic names for which to obtain the information. If this member is null, all associations for the specified Directory ID are returned.
            An empty list results in an InvalidParameterException being thrown.
            (string) --
            
    :type TopicNames: list
    """
    pass

def describe_snapshots(DirectoryId=None, SnapshotIds=None, NextToken=None, Limit=None):
    """
    :param DirectoryId: The identifier of the directory for which to retrieve snapshot information.
    :type DirectoryId: string
    :param SnapshotIds: A list of identifiers of the snapshots to obtain the information for. If this member is null or empty, all snapshots are returned using the Limit and NextToken members.
            (string) --
            
    :type SnapshotIds: list
    :param NextToken: The DescribeSnapshotsResult.NextToken value from a previous call to DescribeSnapshots . Pass null if this is the first call.
    :type NextToken: string
    :param Limit: The maximum number of objects to return.
    :type Limit: integer
    """
    pass

def describe_trusts(DirectoryId=None, TrustIds=None, NextToken=None, Limit=None):
    """
    :param DirectoryId: The Directory ID of the AWS directory that is a part of the requested trust relationship.
    :type DirectoryId: string
    :param TrustIds: A list of identifiers of the trust relationships for which to obtain the information. If this member is null, all trust relationships that belong to the current account are returned.
            An empty list results in an InvalidParameterException being thrown.
            (string) --
            
    :type TrustIds: list
    :param NextToken: The DescribeTrustsResult.NextToken value from a previous call to DescribeTrusts . Pass null if this is the first call.
    :type NextToken: string
    :param Limit: The maximum number of objects to return.
    :type Limit: integer
    """
    pass

def disable_radius(DirectoryId=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to disable MFA.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Contains the results of the DisableRadius operation.
            
            
    :type DirectoryId: string
    """
    pass

def disable_sso(DirectoryId=None, UserName=None, Password=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to disable single-sign on.
            
    :type DirectoryId: string
    :param UserName: The username of an alternate account to use to disable single-sign on. This is only used for AD Connector directories. This account must have privileges to remove a service principal name.
            If the AD Connector service account does not have privileges to remove a service principal name, you can specify an alternate account with the UserName and Password parameters. These credentials are only used to disable single sign-on and are not stored by the service. The AD Connector service account is not changed.
            
    :type UserName: string
    :param Password: The password of an alternate account to use to disable single-sign on. This is only used for AD Connector directories. For more information, see the UserName parameter.
    :type Password: string
    """
    pass

def enable_radius(DirectoryId=None, RadiusSettings=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to enable MFA.
            
    :type DirectoryId: string
    :param RadiusSettings: [REQUIRED]
            A RadiusSettings object that contains information about the RADIUS server.
            RadiusServers (list) --An array of strings that contains the IP addresses of the RADIUS server endpoints, or the IP addresses of your RADIUS server load balancer.
            (string) --
            RadiusPort (integer) --The port that your RADIUS server is using for communications. Your on-premises network must allow inbound traffic over this port from the AWS Directory Service servers.
            RadiusTimeout (integer) --The amount of time, in seconds, to wait for the RADIUS server to respond.
            RadiusRetries (integer) --The maximum number of times that communication with the RADIUS server is attempted.
            SharedSecret (string) --Not currently used.
            AuthenticationProtocol (string) --The protocol specified for your RADIUS endpoints.
            DisplayLabel (string) --Not currently used.
            UseSameUsername (boolean) --Not currently used.
            
    :type RadiusSettings: dict
    """
    pass

def enable_sso(DirectoryId=None, UserName=None, Password=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to enable single-sign on.
            
    :type DirectoryId: string
    :param UserName: The username of an alternate account to use to enable single-sign on. This is only used for AD Connector directories. This account must have privileges to add a service principal name.
            If the AD Connector service account does not have privileges to add a service principal name, you can specify an alternate account with the UserName and Password parameters. These credentials are only used to enable single sign-on and are not stored by the service. The AD Connector service account is not changed.
            
    :type UserName: string
    :param Password: The password of an alternate account to use to enable single-sign on. This is only used for AD Connector directories. For more information, see the UserName parameter.
    :type Password: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_directory_limits():
    """
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_snapshot_limits(DirectoryId=None):
    """
    :param DirectoryId: [REQUIRED]
            Contains the identifier of the directory to obtain the limits for.
            Return typedict
            ReturnsResponse Syntax{
              'SnapshotLimits': {
                'ManualSnapshotsLimit': 123,
                'ManualSnapshotsCurrentCount': 123,
                'ManualSnapshotsLimitReached': True|False
              }
            }
            Response Structure
            (dict) --Contains the results of the GetSnapshotLimits operation.
            SnapshotLimits (dict) --A SnapshotLimits object that contains the manual snapshot limits for the specified directory.
            ManualSnapshotsLimit (integer) --The maximum number of manual snapshots allowed.
            ManualSnapshotsCurrentCount (integer) --The current number of manual snapshots of the directory.
            ManualSnapshotsLimitReached (boolean) --Indicates if the manual snapshot limit has been reached.
            
            
            
    :type DirectoryId: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_ip_routes(DirectoryId=None, NextToken=None, Limit=None):
    """
    :param DirectoryId: [REQUIRED]
            Identifier (ID) of the directory for which you want to retrieve the IP addresses.
            
    :type DirectoryId: string
    :param NextToken: The ListIpRoutes.NextToken value from a previous call to ListIpRoutes . Pass null if this is the first call.
    :type NextToken: string
    :param Limit: Maximum number of items to return. If this value is zero, the maximum number of items is specified by the limitations of the operation.
    :type Limit: integer
    """
    pass

def list_tags_for_resource(ResourceId=None, NextToken=None, Limit=None):
    """
    :param ResourceId: [REQUIRED]
            Identifier (ID) of the directory for which you want to retrieve tags.
            
    :type ResourceId: string
    :param NextToken: Reserved for future use.
    :type NextToken: string
    :param Limit: Reserved for future use.
    :type Limit: integer
    """
    pass

def register_event_topic(DirectoryId=None, TopicName=None):
    """
    :param DirectoryId: [REQUIRED]
            The Directory ID that will publish status messages to the SNS topic.
            
    :type DirectoryId: string
    :param TopicName: [REQUIRED]
            The SNS topic name to which the directory will publish status messages. This SNS topic must be in the same region as the specified Directory ID.
            
    :type TopicName: string
    """
    pass

def remove_ip_routes(DirectoryId=None, CidrIps=None):
    """
    :param DirectoryId: [REQUIRED]
            Identifier (ID) of the directory from which you want to remove the IP addresses.
            
    :type DirectoryId: string
    :param CidrIps: [REQUIRED]
            IP address blocks that you want to remove.
            (string) --
            
    :type CidrIps: list
    """
    pass

def remove_tags_from_resource(ResourceId=None, TagKeys=None):
    """
    :param ResourceId: [REQUIRED]
            Identifier (ID) of the directory from which to remove the tag.
            
    :type ResourceId: string
    :param TagKeys: [REQUIRED]
            The tag key (name) of the tag to be removed.
            (string) --
            
    :type TagKeys: list
    """
    pass

def restore_from_snapshot(SnapshotId=None):
    """
    :param SnapshotId: [REQUIRED]
            The identifier of the snapshot to restore from.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Contains the results of the RestoreFromSnapshot operation.
            
            
    :type SnapshotId: string
    """
    pass

def update_conditional_forwarder(DirectoryId=None, RemoteDomainName=None, DnsIpAddrs=None):
    """
    :param DirectoryId: [REQUIRED]
            The directory ID of the AWS directory for which to update the conditional forwarder.
            
    :type DirectoryId: string
    :param RemoteDomainName: [REQUIRED]
            The fully qualified domain name (FQDN) of the remote domain with which you will set up a trust relationship.
            
    :type RemoteDomainName: string
    :param DnsIpAddrs: [REQUIRED]
            The updated IP addresses of the remote DNS server associated with the conditional forwarder.
            (string) --
            
    :type DnsIpAddrs: list
    """
    pass

def update_radius(DirectoryId=None, RadiusSettings=None):
    """
    :param DirectoryId: [REQUIRED]
            The identifier of the directory for which to update the RADIUS server information.
            
    :type DirectoryId: string
    :param RadiusSettings: [REQUIRED]
            A RadiusSettings object that contains information about the RADIUS server.
            RadiusServers (list) --An array of strings that contains the IP addresses of the RADIUS server endpoints, or the IP addresses of your RADIUS server load balancer.
            (string) --
            RadiusPort (integer) --The port that your RADIUS server is using for communications. Your on-premises network must allow inbound traffic over this port from the AWS Directory Service servers.
            RadiusTimeout (integer) --The amount of time, in seconds, to wait for the RADIUS server to respond.
            RadiusRetries (integer) --The maximum number of times that communication with the RADIUS server is attempted.
            SharedSecret (string) --Not currently used.
            AuthenticationProtocol (string) --The protocol specified for your RADIUS endpoints.
            DisplayLabel (string) --Not currently used.
            UseSameUsername (boolean) --Not currently used.
            
    :type RadiusSettings: dict
    """
    pass

def verify_trust(TrustId=None):
    """
    :param TrustId: [REQUIRED]
            The unique Trust ID of the trust relationship to verify.
            Return typedict
            ReturnsResponse Syntax{
              'TrustId': 'string'
            }
            Response Structure
            (dict) --Result of a VerifyTrust request.
            TrustId (string) --The unique Trust ID of the trust relationship that was verified.
            
            
    :type TrustId: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_tags(ResourceId=None, Tags=None):
    """
    :param ResourceId: [REQUIRED]
            The resource ID of the request.
            
    :type ResourceId: string
    :param Tags: [REQUIRED]
            The tags of the request.
            (dict) --Describes the tag of the WorkSpace.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            
    :type Tags: list
    """
    pass

def create_workspaces(Workspaces=None):
    """
    :param Workspaces: [REQUIRED]
            An array of structures that specify the WorkSpaces to create.
            (dict) --Contains information about a WorkSpace creation request.
            DirectoryId (string) -- [REQUIRED]The identifier of the AWS Directory Service directory to create the WorkSpace in. You can use the DescribeWorkspaceDirectories operation to obtain a list of the directories that are available.
            UserName (string) -- [REQUIRED]The username that the WorkSpace is assigned to. This username must exist in the AWS Directory Service directory specified by the DirectoryId member.
            BundleId (string) -- [REQUIRED]The identifier of the bundle to create the WorkSpace from. You can use the DescribeWorkspaceBundles operation to obtain a list of the bundles that are available.
            VolumeEncryptionKey (string) --The KMS key used to encrypt data stored on your WorkSpace.
            UserVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the user volume, or D: drive, is encrypted.
            RootVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the root volume, or C: drive, is encrypted.
            WorkspaceProperties (dict) --Describes the properties of a WorkSpace.
            RunningMode (string) --The running mode of the WorkSpace. AlwaysOn WorkSpaces are billed monthly. AutoStop WorkSpaces are billed by the hour and stopped when no longer being used in order to save on costs.
            RunningModeAutoStopTimeoutInMinutes (integer) --The time after a user logs off when WorkSpaces are automatically stopped. Configured in 60 minute intervals.
            Tags (list) --The tags of the WorkSpace request.
            (dict) --Describes the tag of the WorkSpace.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceRequest': {
                    'DirectoryId': 'string',
                    'UserName': 'string',
                    'BundleId': 'string',
                    'VolumeEncryptionKey': 'string',
                    'UserVolumeEncryptionEnabled': True|False,
                    'RootVolumeEncryptionEnabled': True|False,
                    'WorkspaceProperties': {
                      'RunningMode': 'AUTO_STOP'|'ALWAYS_ON',
                      'RunningModeAutoStopTimeoutInMinutes': 123
                    },
                    'Tags': [
                      {
                        'Key': 'string',
                        'Value': 'string'
                      },
                    ]
                  },
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ],
              'PendingRequests': [
                {
                  'WorkspaceId': 'string',
                  'DirectoryId': 'string',
                  'UserName': 'string',
                  'IpAddress': 'string',
                  'State': 'PENDING'|'AVAILABLE'|'IMPAIRED'|'UNHEALTHY'|'REBOOTING'|'STARTING'|'REBUILDING'|'MAINTENANCE'|'TERMINATING'|'TERMINATED'|'SUSPENDED'|'STOPPING'|'STOPPED'|'ERROR',
                  'BundleId': 'string',
                  'SubnetId': 'string',
                  'ErrorMessage': 'string',
                  'ErrorCode': 'string',
                  'ComputerName': 'string',
                  'VolumeEncryptionKey': 'string',
                  'UserVolumeEncryptionEnabled': True|False,
                  'RootVolumeEncryptionEnabled': True|False,
                  'WorkspaceProperties': {
                    'RunningMode': 'AUTO_STOP'|'ALWAYS_ON',
                    'RunningModeAutoStopTimeoutInMinutes': 123
                  }
                },
              ]
            }
            Response Structure
            (dict) --Contains the result of the CreateWorkspaces operation.
            FailedRequests (list) --An array of structures that represent the WorkSpaces that could not be created.
            (dict) --Contains information about a WorkSpace that could not be created.
            WorkspaceRequest (dict) --A FailedCreateWorkspaceRequest$WorkspaceRequest object that contains the information about the WorkSpace that could not be created.
            DirectoryId (string) --The identifier of the AWS Directory Service directory to create the WorkSpace in. You can use the DescribeWorkspaceDirectories operation to obtain a list of the directories that are available.
            UserName (string) --The username that the WorkSpace is assigned to. This username must exist in the AWS Directory Service directory specified by the DirectoryId member.
            BundleId (string) --The identifier of the bundle to create the WorkSpace from. You can use the DescribeWorkspaceBundles operation to obtain a list of the bundles that are available.
            VolumeEncryptionKey (string) --The KMS key used to encrypt data stored on your WorkSpace.
            UserVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the user volume, or D: drive, is encrypted.
            RootVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the root volume, or C: drive, is encrypted.
            WorkspaceProperties (dict) --Describes the properties of a WorkSpace.
            RunningMode (string) --The running mode of the WorkSpace. AlwaysOn WorkSpaces are billed monthly. AutoStop WorkSpaces are billed by the hour and stopped when no longer being used in order to save on costs.
            RunningModeAutoStopTimeoutInMinutes (integer) --The time after a user logs off when WorkSpaces are automatically stopped. Configured in 60 minute intervals.
            Tags (list) --The tags of the WorkSpace request.
            (dict) --Describes the tag of the WorkSpace.
            Key (string) --The key of the tag.
            Value (string) --The value of the tag.
            
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            PendingRequests (list) --An array of structures that represent the WorkSpaces that were created.
            Because this operation is asynchronous, the identifier in WorkspaceId is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information will be returned.
            (dict) --Contains information about a WorkSpace.
            WorkspaceId (string) --The identifier of the WorkSpace.
            DirectoryId (string) --The identifier of the AWS Directory Service directory that the WorkSpace belongs to.
            UserName (string) --The user that the WorkSpace is assigned to.
            IpAddress (string) --The IP address of the WorkSpace.
            State (string) --The operational state of the WorkSpace.
            BundleId (string) --The identifier of the bundle that the WorkSpace was created from.
            SubnetId (string) --The identifier of the subnet that the WorkSpace is in.
            ErrorMessage (string) --If the WorkSpace could not be created, this contains a textual error message that describes the failure.
            ErrorCode (string) --If the WorkSpace could not be created, this contains the error code.
            ComputerName (string) --The name of the WorkSpace as seen by the operating system.
            VolumeEncryptionKey (string) --The KMS key used to encrypt data stored on your WorkSpace.
            UserVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the user volume, or D: drive, is encrypted.
            RootVolumeEncryptionEnabled (boolean) --Specifies whether the data stored on the root volume, or C: drive, is encrypted.
            WorkspaceProperties (dict) --Describes the properties of a WorkSpace.
            RunningMode (string) --The running mode of the WorkSpace. AlwaysOn WorkSpaces are billed monthly. AutoStop WorkSpaces are billed by the hour and stopped when no longer being used in order to save on costs.
            RunningModeAutoStopTimeoutInMinutes (integer) --The time after a user logs off when WorkSpaces are automatically stopped. Configured in 60 minute intervals.
            
            
            
            
    :type Workspaces: list
    """
    pass

def delete_tags(ResourceId=None, TagKeys=None):
    """
    :param ResourceId: [REQUIRED]
            The resource ID of the request.
            
    :type ResourceId: string
    :param TagKeys: [REQUIRED]
            The tag keys of the request.
            (string) --
            
    :type TagKeys: list
    """
    pass

def describe_tags(ResourceId=None):
    """
    :param ResourceId: [REQUIRED]
            The resource ID of the request.
            Return typedict
            ReturnsResponse Syntax{
              'TagList': [
                {
                  'Key': 'string',
                  'Value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --The result of the DescribeTags operation.
            TagList (list) --The list of tags.
            (dict) --Describes the tag of the WorkSpace.
            Key (string) --The key of the tag.
            Value (string) --The value of the tag.
            
            
            
    :type ResourceId: string
    """
    pass

def describe_workspace_bundles(BundleIds=None, Owner=None, NextToken=None):
    """
    :param BundleIds: An array of strings that contains the identifiers of the bundles to retrieve. This parameter cannot be combined with any other filter parameter.
            (string) --
            
    :type BundleIds: list
    :param Owner: The owner of the bundles to retrieve. This parameter cannot be combined with any other filter parameter.
            This contains one of the following values:
            null- Retrieves the bundles that belong to the account making the call.
            AMAZON - Retrieves the bundles that are provided by AWS.
            
    :type Owner: string
    :param NextToken: The NextToken value from a previous call to this operation. Pass null if this is the first call.
    :type NextToken: string
    """
    pass

def describe_workspace_directories(DirectoryIds=None, NextToken=None):
    """
    :param DirectoryIds: An array of strings that contains the directory identifiers to retrieve information for. If this member is null, all directories are retrieved.
            (string) --
            
    :type DirectoryIds: list
    :param NextToken: The NextToken value from a previous call to this operation. Pass null if this is the first call.
    :type NextToken: string
    """
    pass

def describe_workspaces(WorkspaceIds=None, DirectoryId=None, UserName=None, BundleId=None, Limit=None, NextToken=None):
    """
    :param WorkspaceIds: An array of strings that contain the identifiers of the WorkSpaces for which to retrieve information. This parameter cannot be combined with any other filter parameter.
            Because the CreateWorkspaces operation is asynchronous, the identifier it returns is not immediately available. If you immediately call DescribeWorkspaces with this identifier, no information is returned.
            (string) --
            
    :type WorkspaceIds: list
    :param DirectoryId: Specifies the directory identifier to which to limit the WorkSpaces. Optionally, you can specify a specific directory user with the UserName parameter. This parameter cannot be combined with any other filter parameter.
    :type DirectoryId: string
    :param UserName: Used with the DirectoryId parameter to specify the directory user for whom to obtain the WorkSpace.
    :type UserName: string
    :param BundleId: The identifier of a bundle to obtain the WorkSpaces for. All WorkSpaces that are created from this bundle will be retrieved. This parameter cannot be combined with any other filter parameter.
    :type BundleId: string
    :param Limit: The maximum number of items to return.
    :type Limit: integer
    :param NextToken: The NextToken value from a previous call to this operation. Pass null if this is the first call.
    :type NextToken: string
    """
    pass

def describe_workspaces_connection_status(WorkspaceIds=None, NextToken=None):
    """
    :param WorkspaceIds: An array of strings that contain the identifiers of the WorkSpaces.
            (string) --
            
    :type WorkspaceIds: list
    :param NextToken: The next token of the request.
    :type NextToken: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def modify_workspace_properties(WorkspaceId=None, WorkspaceProperties=None):
    """
    :param WorkspaceId: [REQUIRED]
            The ID of the WorkSpace.
            
    :type WorkspaceId: string
    :param WorkspaceProperties: [REQUIRED]
            The WorkSpace properties of the request.
            RunningMode (string) --The running mode of the WorkSpace. AlwaysOn WorkSpaces are billed monthly. AutoStop WorkSpaces are billed by the hour and stopped when no longer being used in order to save on costs.
            RunningModeAutoStopTimeoutInMinutes (integer) --The time after a user logs off when WorkSpaces are automatically stopped. Configured in 60 minute intervals.
            
    :type WorkspaceProperties: dict
    """
    pass

def reboot_workspaces(RebootWorkspaceRequests=None):
    """
    :param RebootWorkspaceRequests: [REQUIRED]
            An array of structures that specify the WorkSpaces to reboot.
            (dict) --Contains information used with the RebootWorkspaces operation to reboot a WorkSpace.
            WorkspaceId (string) -- [REQUIRED]The identifier of the WorkSpace to reboot.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --Contains the results of the RebootWorkspaces operation.
            FailedRequests (list) --An array of structures representing any WorkSpaces that could not be rebooted.
            (dict) --Contains information about a WorkSpace that could not be rebooted ( RebootWorkspaces ), rebuilt ( RebuildWorkspaces ), terminated ( TerminateWorkspaces ), started ( StartWorkspaces ), or stopped ( StopWorkspaces ).
            WorkspaceId (string) --The identifier of the WorkSpace.
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            
            
    :type RebootWorkspaceRequests: list
    """
    pass

def rebuild_workspaces(RebuildWorkspaceRequests=None):
    """
    :param RebuildWorkspaceRequests: [REQUIRED]
            An array of structures that specify the WorkSpaces to rebuild.
            (dict) --Contains information used with the RebuildWorkspaces operation to rebuild a WorkSpace.
            WorkspaceId (string) -- [REQUIRED]The identifier of the WorkSpace to rebuild.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --Contains the results of the RebuildWorkspaces operation.
            FailedRequests (list) --An array of structures representing any WorkSpaces that could not be rebuilt.
            (dict) --Contains information about a WorkSpace that could not be rebooted ( RebootWorkspaces ), rebuilt ( RebuildWorkspaces ), terminated ( TerminateWorkspaces ), started ( StartWorkspaces ), or stopped ( StopWorkspaces ).
            WorkspaceId (string) --The identifier of the WorkSpace.
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            
            
    :type RebuildWorkspaceRequests: list
    """
    pass

def start_workspaces(StartWorkspaceRequests=None):
    """
    :param StartWorkspaceRequests: [REQUIRED]
            The requests.
            (dict) --Describes the start request.
            WorkspaceId (string) --The ID of the WorkSpace.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            FailedRequests (list) --The failed requests.
            (dict) --Contains information about a WorkSpace that could not be rebooted ( RebootWorkspaces ), rebuilt ( RebuildWorkspaces ), terminated ( TerminateWorkspaces ), started ( StartWorkspaces ), or stopped ( StopWorkspaces ).
            WorkspaceId (string) --The identifier of the WorkSpace.
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            
            
    :type StartWorkspaceRequests: list
    """
    pass

def stop_workspaces(StopWorkspaceRequests=None):
    """
    :param StopWorkspaceRequests: [REQUIRED]
            The requests.
            (dict) --Describes the stop request.
            WorkspaceId (string) --The ID of the WorkSpace.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            FailedRequests (list) --The failed requests.
            (dict) --Contains information about a WorkSpace that could not be rebooted ( RebootWorkspaces ), rebuilt ( RebuildWorkspaces ), terminated ( TerminateWorkspaces ), started ( StartWorkspaces ), or stopped ( StopWorkspaces ).
            WorkspaceId (string) --The identifier of the WorkSpace.
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            
            
    :type StopWorkspaceRequests: list
    """
    pass

def terminate_workspaces(TerminateWorkspaceRequests=None):
    """
    :param TerminateWorkspaceRequests: [REQUIRED]
            An array of structures that specify the WorkSpaces to terminate.
            (dict) --Contains information used with the TerminateWorkspaces operation to terminate a WorkSpace.
            WorkspaceId (string) -- [REQUIRED]The identifier of the WorkSpace to terminate.
            
            Return typedict
            ReturnsResponse Syntax{
              'FailedRequests': [
                {
                  'WorkspaceId': 'string',
                  'ErrorCode': 'string',
                  'ErrorMessage': 'string'
                },
              ]
            }
            Response Structure
            (dict) --Contains the results of the TerminateWorkspaces operation.
            FailedRequests (list) --An array of structures representing any WorkSpaces that could not be terminated.
            (dict) --Contains information about a WorkSpace that could not be rebooted ( RebootWorkspaces ), rebuilt ( RebuildWorkspaces ), terminated ( TerminateWorkspaces ), started ( StartWorkspaces ), or stopped ( StopWorkspaces ).
            WorkspaceId (string) --The identifier of the WorkSpace.
            ErrorCode (string) --The error code.
            ErrorMessage (string) --The textual error message.
            
            
            
    :type TerminateWorkspaceRequests: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def batch_delete_attributes(DomainName=None, Items=None):
    """
    :param DomainName: [REQUIRED] The name of the domain in which the attributes are being deleted.
    :type DomainName: string
    :param Items: [REQUIRED] A list of items on which to perform the operation.
            (dict) --
            Name (string) -- [REQUIRED]
            Attributes (list) --
            (dict) --
            Name (string) -- [REQUIRED] The name of the attribute.
            AlternateNameEncoding (string) --
            Value (string) -- [REQUIRED] The value of the attribute.
            AlternateValueEncoding (string) --
            
            
    :type Items: list
    """
    pass

def batch_put_attributes(DomainName=None, Items=None):
    """
    :param DomainName: [REQUIRED] The name of the domain in which the attributes are being stored.
    :type DomainName: string
    :param Items: [REQUIRED] A list of items on which to perform the operation.
            (dict) --
            Name (string) -- [REQUIRED] The name of the replaceable item.
            Attributes (list) -- [REQUIRED] The list of attributes for a replaceable item.
            (dict) --
            Name (string) -- [REQUIRED] The name of the replaceable attribute.
            Value (string) -- [REQUIRED] The value of the replaceable attribute.
            Replace (boolean) -- A flag specifying whether or not to replace the attribute/value pair or to add a new attribute/value pair. The default setting is false .
            
            
    :type Items: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED] The name of the domain to create. The name can range between 3 and 255 characters and can contain the following characters: a-z, A-Z, 0-9, '_', '-', and '.'.
            ReturnsNone
            
    :type DomainName: string
    """
    pass

def delete_attributes(DomainName=None, ItemName=None, Attributes=None, Expected=None):
    """
    :param DomainName: [REQUIRED] The name of the domain in which to perform the operation.
    :type DomainName: string
    :param ItemName: [REQUIRED] The name of the item. Similar to rows on a spreadsheet, items represent individual objects that contain one or more value-attribute pairs.
    :type ItemName: string
    :param Attributes: A list of Attributes. Similar to columns on a spreadsheet, attributes represent categories of data that can be assigned to items.
            (dict) --
            Name (string) -- [REQUIRED] The name of the attribute.
            AlternateNameEncoding (string) --
            Value (string) -- [REQUIRED] The value of the attribute.
            AlternateValueEncoding (string) --
            
    :type Attributes: list
    :param Expected: The update condition which, if specified, determines whether the specified attributes will be deleted or not. The update condition must be satisfied in order for this request to be processed and the attributes to be deleted.
            Name (string) --The name of the attribute involved in the condition.
            Value (string) --The value of an attribute. This value can only be specified when the Exists parameter is equal to true .
            Exists (boolean) --A value specifying whether or not the specified attribute must exist with the specified value in order for the update condition to be satisfied. Specify true if the attribute must exist for the update condition to be satisfied. Specify false if the attribute should not exist in order for the update condition to be satisfied.
            
    :type Expected: dict
    """
    pass

def delete_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED] The name of the domain to delete.
            ReturnsNone
            
    :type DomainName: string
    """
    pass

def domain_metadata(DomainName=None):
    """
    :param DomainName: [REQUIRED] The name of the domain for which to display the metadata of.
            Return typedict
            ReturnsResponse Syntax{
              'ItemCount': 123,
              'ItemNamesSizeBytes': 123,
              'AttributeNameCount': 123,
              'AttributeNamesSizeBytes': 123,
              'AttributeValueCount': 123,
              'AttributeValuesSizeBytes': 123,
              'Timestamp': 123
            }
            Response Structure
            (dict) --
            ItemCount (integer) -- The number of all items in the domain.
            ItemNamesSizeBytes (integer) -- The total size of all item names in the domain, in bytes.
            AttributeNameCount (integer) -- The number of unique attribute names in the domain.
            AttributeNamesSizeBytes (integer) -- The total size of all unique attribute names in the domain, in bytes.
            AttributeValueCount (integer) -- The number of all attribute name/value pairs in the domain.
            AttributeValuesSizeBytes (integer) -- The total size of all attribute values in the domain, in bytes.
            Timestamp (integer) -- The data and time when metadata was calculated, in Epoch (UNIX) seconds.
            
            
    :type DomainName: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_attributes(DomainName=None, ItemName=None, AttributeNames=None, ConsistentRead=None):
    """
    :param DomainName: [REQUIRED] The name of the domain in which to perform the operation.
    :type DomainName: string
    :param ItemName: [REQUIRED] The name of the item.
    :type ItemName: string
    :param AttributeNames: The names of the attributes.
            (string) --
            
    :type AttributeNames: list
    :param ConsistentRead: Determines whether or not strong consistency should be enforced when data is read from SimpleDB. If true , any data previously written to SimpleDB will be returned. Otherwise, results will be consistent eventually, and the client may not see data that was written immediately before your read.
    :type ConsistentRead: boolean
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_domains(MaxNumberOfDomains=None, NextToken=None):
    """
    :param MaxNumberOfDomains: The maximum number of domain names you want returned. The range is 1 to 100. The default setting is 100.
    :type MaxNumberOfDomains: integer
    :param NextToken: A string informing Amazon SimpleDB where to start the next list of domain names.
    :type NextToken: string
    """
    pass

def put_attributes(DomainName=None, ItemName=None, Attributes=None, Expected=None):
    """
    :param DomainName: [REQUIRED] The name of the domain in which to perform the operation.
    :type DomainName: string
    :param ItemName: [REQUIRED] The name of the item.
    :type ItemName: string
    :param Attributes: [REQUIRED] The list of attributes.
            (dict) --
            Name (string) -- [REQUIRED] The name of the replaceable attribute.
            Value (string) -- [REQUIRED] The value of the replaceable attribute.
            Replace (boolean) -- A flag specifying whether or not to replace the attribute/value pair or to add a new attribute/value pair. The default setting is false .
            
    :type Attributes: list
    :param Expected: The update condition which, if specified, determines whether the specified attributes will be updated or not. The update condition must be satisfied in order for this request to be processed and the attributes to be updated.
            Name (string) --The name of the attribute involved in the condition.
            Value (string) --The value of an attribute. This value can only be specified when the Exists parameter is equal to true .
            Exists (boolean) --A value specifying whether or not the specified attribute must exist with the specified value in order for the update condition to be satisfied. Specify true if the attribute must exist for the update condition to be satisfied. Specify false if the attribute should not exist in order for the update condition to be satisfied.
            
    :type Expected: dict
    """
    pass

def select(SelectExpression=None, NextToken=None, ConsistentRead=None):
    """
    :param SelectExpression: [REQUIRED] The expression used to query the domain.
    :type SelectExpression: string
    :param NextToken: A string informing Amazon SimpleDB where to start the next list of ItemNames .
    :type NextToken: string
    :param ConsistentRead: Determines whether or not strong consistency should be enforced when data is read from SimpleDB. If true , any data previously written to SimpleDB will be returned. Otherwise, results will be consistent eventually, and the client may not see data that was written immediately before your read.
    :type ConsistentRead: boolean
    """
    pass

